@@ -101,7 +101,7 @@ _SEQDB = {
     '< CSI <m'           : 'SGR (1006) mouse reporting, button up (code, row, col)',
     '< CSI [0]I'         : 'Focus mode reporting: focus in',
     '< CSI [0]O'         : 'Focus mode reporting: focus out',
-    '< CSI [3]R'         : 'DSR-DECXCPR(cursor position report) response, DEC specific: (row=%s,col=%s,page=%s)',
+    '< CSI ?[3]R'        : 'DSR-DECXCPR(cursor position report) response, DEC specific: (row=%s,col=%s,page=%s)',
     '< CSI [2]R'         : 'DSR-CPR(cursor position report) response: (row=%s,col=%s)',
     '< CSI R'            : 'DSR-CPR(cursor position report) response',
     '< CSI 0n'           : 'DSR-OS(operating status report) response: "good status"',
@@ -111,24 +111,22 @@ _SEQDB = {
     '< CSI ?c'           : 'DA1 Response',
     '< CSI ?1;0c'        : 'DA1 Response: VT100 with no options (could be WizConsole VT100 mode)',
     '< CSI ?1;2c'        : 'DA1 Response: VT100 with AVO (could be a VT102/rxvt/rxvt-unicode/konsole/kterm/mlterm/iTerm2/tmux/aterm/wterm/Terminal.app(Mac)/mrxvt/MinTTY/TeraTerm/ck)',
-    '< CSI ?6c'          : 'DA1 Response: VT102 (could be linux xvt/console/PuTTY/Terminal.app(GNUStep)/yaft)',
+    '< CSI ?1;6c'        : 'DA1 Response: VT100 with AVO and GPO (could be MacTerm)',
+    '< CSI ?1;2;4;7c'    : 'DA1 Response: mlterm(3.1.7 or later) with Sixel/DRCS',
+    '< CSI ?1;2;4c'      : 'DA1 Response: mlterm(3.1.7 or later) with DRCS',
+    '< CSI ?6c'          : 'DA1 Response: VT102 (could be linux xvt/console/PuTTY/Terminal.app(GNUStep)/yaft/Cathode)',
     '< CSI ?62c'         : 'DA1 Response: VT200 family (could be mosh/WizConsole VT200 mode)',
     '< CSI ?62;9;c'      : 'DA1 Response: VT200 family (could be gnome-terminal)',
-    '< CSI ?64;1;2;6;9;15;21;22c':
-    'DA1 Response: VT400 family (could be xterm pl>=280)',
-    '< CSI >64;1;4;7;9;22;29c':
-    'DA2 Response: VT400 family (could be tanasinn)',
-    '< CSI ?65;1;2;3,4;6;8;9;18;21;22;29;42;44c':
-    'DA1 Response: VT500 family (could be RLogin)',
-    '< CSI ?65;1;2;3;4;6;8;9;18;21;22;29;42;44c':
-    'DA1 Response: VT500 family (could be RLogin)',
+    '< CSI ?64;1;2;6;9;15;21;22c': 'DA1 Response: VT400 family (could be xterm pl>=280)',
+    '< CSI ?64;1;4;7;9;22;29c': 'DA1 Response: VT400 family (could be tanasinn)',
+    '< CSI ?65;1;2;3;4;6;8;9;18;21;22;29;42;44c': 'DA1 Response: VT500 family (could be RLogin)',
     '< CSI >c'           : 'DA2 Response',
     '< CSI >0;[2]c'      : 'DA2 Response: VT100, Pv=%s, keyboard type=%s',
-    '< CSI >0;95;c'      : 'DA2 Response: xterm pattch#95 (could be iTerm/iTerm2)',
-    '< CSI >0;95;0c'     : 'DA2 Response: xterm pattch#95 (could be tmux/)',
-    '< CSI >0;95;1c'     : 'DA2 Response: xterm pattch#95 (could be avaliable mouse)',
-    '< CSI >0;115;0c'    : 'DA2 Response: xterm pattch#115 (could be Konsole)',
-    '< CSI >0;136;0c'    : 'DA2 Response: xterm pattch#136 (could be PuTTY)',
+    '< CSI >0;95;c'      : 'DA2 Response: xterm patch#95 (could be iTerm/iTerm2)',
+    '< CSI >0;95;0c'     : 'DA2 Response: xterm patch#95 (could be tmux)',
+    '< CSI >0;95;1c'     : 'DA2 Response: xterm patch#95 (could be avaliable mouse)',
+    '< CSI >0;115;0c'    : 'DA2 Response: xterm patch#115 (could be Konsole)',
+    '< CSI >0;136;0c'    : 'DA2 Response: xterm patch#136 (could be PuTTY)',
     '< CSI >0;270;0c'    : 'DA2 Response: VT100 (could be xterm patch#270)',
     '< CSI >0;271;0c'    : 'DA2 Response: VT100 (could be xterm patch#271)',
     '< CSI >0;272;0c'    : 'DA2 Response: VT100 (could be xterm patch#272)',
@@ -141,7 +139,7 @@ _SEQDB = {
     '< CSI >0;279;0c'    : 'DA2 Response: VT100 (could be xterm patch#279)',
     '< CSI >1;[2]c'      : 'DA2 Response: VT220, Pv=%s, keyboard type=%s',
     '< CSI >1;10;0c'     : 'DA2 Response: VT220 (could be mosh/WizConsole VT200 mode)',
-    '< CSI >1;96;0c'     : 'DA2 Response: VT220 (could be xterm pattch#96, mlterm)',
+    '< CSI >1;96;0c'     : 'DA2 Response: VT220 (could be mlterm)',
     '< CSI >1;2403;0c'   : 'DA2 Response: VT220 (could be VTE, such as gnome-terminal)',
     '< CSI >1;2802;0c'   : 'DA2 Response: VT220 (could be VTE, such as gnome-terminal)',
     '< CSI >2;[2]c'      : 'DA2 Response: VT240, Pv=%s, keyboard type=%s',
@@ -151,6 +149,7 @@ _SEQDB = {
     '< CSI >24;[2]c'     : 'DA2 Response: VT320, Pv=%s, keyboard type=%s',
     '< CSI >32;[2]c'     : 'DA2 Response: VT382, Pv=%s, keyboard type=%s',
     '< CSI >32;100;2c'   : 'DA2 Response: VT382 (could be TeraTerm)',
+    '< CSI >32;277;2c'   : 'DA2 Response: VT382 (could be mouseterm-plus)',
     '< CSI >41;[2]c'     : 'DA2 Response: VT420, Pv=%s, keyboard type=%s',
     '< CSI >41;280;0c'   : 'DA2 Response: VT420 (could be xterm patch#280)',
     '< CSI >41;281;0c'   : 'DA2 Response: VT420 (could be xterm patch#281)',
@@ -168,7 +167,7 @@ _SEQDB = {
     '< CSI >61;[2]c'     : 'DA2 Response: VT510, Pv=%s, keyboard type=%s',
     '< CSI >64;[2]c'     : 'DA2 Response: VT520, Pv=%s, keyboard type=%s',
     '< CSI >65;[2]c'     : 'DA2 Response: VT525, Pv=%s, keyboard type=%s',
-    '< CSI >65;100;1c'   : 'DA1 Response: VT500 family (could be RLogin)',
+    '< CSI >65;100;1c'   : 'DA2 Response: VT500 family (could be RLogin)',
     '< CSI >77;[2]c'     : 'DA2 Response: could be MinTTY, Pv=%s, keyboard type=%s',
     '< CSI >77;[1];c'    : 'DA2 Response: could be MinTTY, Pv=%s',
     '< CSI >77;10003;c'  : 'DA2 Response: could be MinTTY 1.0.3',
@@ -292,7 +291,7 @@ _SEQDB = {
     '> ESC ]7770<ST>'    : 'OSC 7770 / manipulate font size (MinTTY)',
     '> ESC ]7770;?<ST>'  : 'OSC 7770 / query font size (MinTTY)',
     '> ESC ]7771<ST>'    : 'OSC 7771 / font coverage (MinTTY)',
-    '> ESC ]8900<ST>'    : 'OSC 8890 - GWREPT / glyph width report (yaft)',
+    '> ESC ]8900<ST>'    : 'OSC 8900 - GWREPT / glyph width report (yaft)',
     '> ESC X<ST>'        : 'SOS / start of string',
     '> ESC ^<ST>'        : 'PM / private message',
     '> ESC _<ST>'        : 'APC / application program command',
@@ -570,9 +569,9 @@ _SEQDB = {
     '> CSI ?8428l'       : 'DECRST 8428 / treat ambiguous characters as wide(RLogin)',
     '> CSI ?8441l'       : 'DECRST 8441 / IME close(RLogin)',
     '> CSI m'            : 'SGR / select graphics rendition',
-    '> CSI 0m'           : 'SGR 0 / reset',
-    '> CSI 00m'          : 'SGR 0 / reset',
-    '> CSI [0]m'         : 'SGR 0 / reset',
+    '> CSI 0m'           : 'SGR 0 / reset attributes',
+    '> CSI 00m'          : 'SGR 0 / reset attributes',
+    '> CSI [0]m'         : 'SGR 0 / reset attributes',
     '> CSI 1m'           : 'SGR 1 / bold',
     '> CSI 4m'           : 'SGR 4 / underlined',
     '> CSI 5m'           : 'SGR 5 / blink',
